@@ -20,6 +20,8 @@
 //! - It has an API crate where hooks are defined [irust_api](https://github.com/sigmaSd/IRust/blob/master/crates/irust_api/src/lib.rs#L22)
 //! - It trigger hooks on the main crate [irust](https://github.com/sigmaSd/IRust/blob/master/crates/irust/src/irust.rs#L136)
 //! - And a script example [vim_mode](https://github.com/sigmaSd/IRust/tree/master/scripts_examples/script4/irust_vim)
+//!
+//! Check out the [examples](https://github.com/sigmaSd/Rscript/tree/master/examples) for more info.
 
 use serde::{de::DeserializeOwned, Deserialize, Serialize};
 use std::{
@@ -268,7 +270,7 @@ impl Script {
 ///     const NAME: &'static str = "Eval";
 ///     type Output = Option<String>;
 /// }
-pub trait Hook: Serialize {
+pub trait Hook: Serialize + DeserializeOwned {
     /// The name of the hook, required to distinguish the received hook on the script side
     const NAME: &'static str;
     /// The output type of the script
